<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_SEND","Send");
define("_URL","URL");
define("_EMAIL","Email");
define("_FUNCTIONS","Functions");
define("_YES","Yes");
define("_NO","No");
define("_ALLTOPICS","All Topics");
define("_CATEGORY","Category");
define("_REQUIRED","(required)");
define("_SAVECHANGES","Save Changes");
define("_OK","Ok!");
define("_SAVE","Save");
define("_ID","ID");
define("_SCORE","Score:");
define("_NOSUBJECT","No Subject");
define("_SUBJECT","Subject");
define("_HELLO","Hello");
define("_CATEGORIES","Categories");
define("_WHOSONLINE","Who's Online");
define("_PRODUCTTITLE","Product Title");
define("_RELATEDLINK","Related Link");
define("_LINKTITLE","Link Title");
define("_REVIEWER","Reviewer:");
define("_REVIEWID","Review ID");
define("_HITS","Hits");
define("_THEREARE","There are");
define("_REVIEWS","Reviews");
define("_ARTICLES","Articles");
define("_ALL","All");
define("_PAGEBREAK","If you want multiple pages you can write <b>&lt;!--pagebreak--&gt;</b> where you want to cut.");
define("_DONTSELECT","Note: Don't select any section to store the text and publish it later.");
define("_AREYOUSURE","Are you sure you included a URL? Did you test them for typos?");
define("_SELECTTOPIC","Select Topic");
define("_PREVIEW","Preview");
define("_ICQ","ICQ Number");
define("_AIM","AIM Number");
define("_YIM","YIM Number");
define("_MSNM","MSNM Number");
define("_LOCATION","Location");
define("_OCCUPATION","Occupation");
define("_INTERESTS","Interests");
define("_SIGNATURE","Signature");
define("_EXTRAINFO","Extra Info");
define("_OPTION","Option");
define("_YOUARELOGGEDOUT","You are now logged out!");
define("_HOMECONFIG","Home Configuration");
define("_CHECK","Check");
define("_AUTHORNAME","Author's Name");
define("_AUTHOREMAIL","Author's Email");
define("_DOWNLOADNAME","Program Name");
define("_INBYTES","in bytes");
define("_FILESIZE","Filesize");
define("_VERSION","Version");
define("_DESCRIPTION","Description");
define("_AUTHOR","Author");
define("_HOMEPAGE","HomePage");
define("_NAME","Name");
define("_FILEURL","File Link");
define("_DOWNLOADID","Download ID");
define("_FROM","From");
define("_DATE","Date");
define("_TO","To");
define("_SUBMIT","Submit");
define("_USERNOTINDB","The selected user doesn't exist in the database.");
define("_PAGETITLE","Page Title");
define("_PAGEURL","Page URL");
define("_ADDURL","Add this URL");
define("_SHOW","Show");
define("_DAYS","days");
define("_STAFF","Staff");
define("_LINKID","Link ID");
define("_ADMINID","Admin ID");
define("_ADMINLOGIN","Administration System Login");
define("_FAQ","FAQ");
define("_DOWNLOAD","Download");
define("_WEBLINKS","Web Links");
define("_EDITADMINS","Edit Admins");
define("_PREFERENCES","Preferences");
define("_ADMPOLLS","Surveys/Polls");
define("_SECTIONSMANAGER","Sections Manager");
define("_ADDSTORY","Add Story");
define("_EDITUSERS","Edit Users");
define("_ADMINMENU","Administration Menu");
define("_BANNERSADMIN","Banners Administration");
define("_ONLINEMANUAL","Online Manual");
define("_ADMINLOGOUT","Logout / Exit");
define("_LAST","Last");
define("_GO","Go!");
define("_CURRENTPOLL","Current Poll");
define("_STORYID","Story ID");
define("_ACTIVEBANNERS","Current Active Banners");
define("_ACTIVEBANNERS2","Active Banners");
define("_IMPRESSIONS","Impressions");
define("_IMPLEFT","Imp. Left");
define("_CLICKS","Clicks");
define("_CLICKSPERCENT","% Clicks");
define("_CLIENTNAME","Client Name");
define("_FINISHEDBANNERS","Finished Banners");
define("_IMP","Imp.");
define("_DATESTARTED","Date Started");
define("_DATEENDED","Date Ended");
define("_ADVERTISINGCLIENTS","Advertising Clients");
define("_CONTACTNAME","Contact Name");
define("_CONTACTEMAIL","Contact Email");
define("_ADDNEWBANNER","Add a New Banner");
define("_PURCHASEDIMPRESSIONS","Purchased Impressions");
define("_IMAGEURL","Image URL");
define("_CLICKURL","Click URL");
define("_ADDBANNER","Add Banner");
define("_ADDCLIENT","Add a New Client");
define("_CLIENTLOGIN","Client Login");
define("_CLIENTPASSWD","Client Password");
define("_ADDCLIENT2","Add Client");
define("_BANNERSNOTACTIVE","Banners variable in config.php file is set to 0, this means that you can't see your Banners until you activate it.");
define("_TOACTIVATE","To do this, just change the value from <a href=\"admin.php?op=Configure#banners\">settings section</a>.");
define("_IMPORTANTNOTE","Important Note!");
define("_DELETEBANNER","Delete Banner");
define("_SURETODELBANNER","Are you sure you want to delete this Banner?");
define("_EDITBANNER","Edit Banner");
define("_ADDIMPRESSIONS","Add More Impressions");
define("_PURCHASED","Purchased");
define("_MADE","Made");
define("_DELETECLIENT","Delete Advertising Client");
define("_SURETODELCLIENT","You are about to delete the client and all its Banners!!!");
define("_CLIENTWITHOUTBANNERS","This client doesn't have any banner running now.");
define("_DELCLIENTHASBANNERS","This client has the following ACTIVE BANNERS running now");
define("_EDITCLIENT","Edit Advertising Client");
define("_REMOVECOMMENTS","Delete Comments");
define("_SURETODELCOMMENTS","Are you sure you want to delete selected Comment and all its replies?");
define("_BLOCKSADMIN","Blocks Administration");
define("_BLOCKS","Blocks");
define("_TITLE","Title");
define("_POSITION","Position");
define("_WEIGHT","Weight");
define("_STATUS","Status");
define("_LEFTBLOCK","Left Block");
define("_LEFT","Left");
define("_RIGHTBLOCK","Right Block");
define("_RIGHT","Right");
define("_ACTIVE","Active");
define("_DEACTIVATE","Deactivate");
define("_INACTIVE","Inactive");
define("_ACTIVATE","Activate");
define("_TYPE","Type");
define("_ADDNEWBLOCK","Add a New Block");
define("_RSSFILE","RSS/RDF file URL");
define("_ONLYHEADLINES","(Only for Headlines)");
define("_CONTENT","Content");
define("_ACTIVATE2","Activate?");
define("_REFRESHTIME","Refresh Time");
define("_HOUR","Hour");
define("_CREATEBLOCK","Create Block");
define("_EDITBLOCK","Edit Block");
define("_BLOCK","Block");
define("_SAVEBLOCK","Save Block");
define("_BLOCKACTIVATION","Block Activation");
define("_BLOCKPREVIEW","This is the preview for Block");
define("_WANT2ACTIVATE","Do you want to Activate this block?");
define("_ARESUREDELBLOCK","Are you sure you want to remove Block");
define("_RSSFAIL","There is a problem with the RSS file URL");
define("_RSSTRYAGAIN","Please check the URL and RSS file name, then try again.");
define("_RSSCONTENT","(RSS/RDF Content)");
define("_IFRSSWARNING","If you fill the URL the content you write will not be displayed!");
define("_BLOCKUP","Block UP");
define("_BLOCKDOWN","Block DOWN");
define("_SETUPHEADLINES","(Select Custom and write the URL or just select a Site from the list to grab news headlines)");
define("_HEADLINESADMIN","Headlines Administration");
define("_ADDHEADLINE","Add Headline");
define("_EDITHEADLINE","Edit Headlines");
define("_SURE2DELHEADLINE","WARNING: Are you sure you want to delete this Headline?");
define("_CUSTOM","Custom");
define("_FAQADMIN","FAQ Administration");
define("_ACTIVEFAQS","Active FAQs");
define("_ADDCATEGORY","Add a New Category");
define("_QUESTIONS","Questions and Answers");
define("_ADDQUESTION","Add a New Question");
define("_QUESTION","Question");
define("_ANSWER","Answer");
define("_EDITCATEGORY","Edit Category");
define("_EDITQUESTIONS","Edit Questions and Answers");
define("_FAQDELWARNING","WARNING: Are you sure you want to delete this Faq and all its content?");
define("_QUESTIONDEL","WARNING: Are you sure you want to delete this Question?");
define("_AUTHORSADMIN","Author's Administration");
define("_MODIFYINFO","Modify Info");
define("_DELAUTHOR","Delete Author");
define("_ADDAUTHOR","Add a New Administrator");
define("_PERMISSIONS","Permissions");
define("_TOPICS","Topics");
define("_USERS","Users");
define("_SURVEYS","Surveys");
define("_SECTIONS","Sections");
define("_SUPERUSER","Super User");
define("_SUPERWARNING","WARNING: If Super User is checked, the user will get full access!");
define("_ADDAUTHOR2","Add Author");
define("_RETYPEPASSWD","Retype Password");
define("_FORCHANGES","(For Changes Only)");
define("_COMPLETEFIELDS","You must complete all compulsory fields");
define("_CREATIONERROR","Author's Creation Error");
define("_AUTHORDELSURE","Are you sure you want to delete");
define("_AUTHORDEL","Delete Autor");
define("_REQUIREDNOCHANGE","(required, can't be changed later)");
define("_PUBLISHEDSTORIES","This administrator has published stories");
define("_SELECTNEWADMIN","Please select a new admin to re-assign them");
define("_GODNOTDEL","*(GOD account can't be deleted)");
define("_MAINACCOUNT","God Admin*");
define("_ARTICLEADMIN","Articles/Stories Administration");
define("_ADDARTICLE","Add New Article");
define("_STORYTEXT","Story Text");
define("_EXTENDEDTEXT","Extended Text");
define("_ARESUREURL","(Are you sure you included an URL? Did you test it for typos?)");
define("_PUBLISHINHOME","Publish in Home?");
define("_ONLYIFCATSELECTED","Only works if <i>Articles</i> category isn't selected");
define("_ADD","Add");
define("_PROGRAMSTORY","Do you want to program this story?");
define("_NOWIS","Now is");
define("_DAY","Day");
define("_UMONTH","Month");
define("_YEAR","Year");
define("_PREVIEWSTORY","Preview Story");
define("_POSTSTORY","Post Story");
define("_AUTOMATEDARTICLES","Programmed Articles");
define("_NOAUTOARTICLES","There are no programmed articles");
define("_REMOVESTORY","Are you sure you want to remove Story ID #");
define("_ANDCOMMENTS","and all it's comments?");
define("_CATEGORIESADMIN","Categories Administration");
define("_CATEGORYADD","Add a New Category");
define("_CATNAME","Category Name");
define("_NOARTCATEDIT","You can't edit <i>Articles</i> Category");
define("_ASELECTCATEGORY","Select Category");
define("_CATEGORYNAME","Category Name");
define("_DELETECATEGORY","Delete Category");
define("_SELECTCATDEL","Select a Category to Delete");
define("_CATDELETED","Category Deleted!");
define("_WARNING","Warning");
define("_THECATEGORY","The Category");
define("_HAS","has");
define("_STORIESINSIDE","stories inside");
define("_DELCATWARNING1","You can Delete this Category and ALL its stories and comments");
define("_DELCATWARNING2","or you can Move ALL the stories to a New Category.");
define("_DELCATWARNING3","What do you want to do?");
define("_YESDEL","Yes! Delete ALL!");
define("_NOMOVE","No! Move my Stories");
define("_MOVESTORIES","Move Stories to a New Category");
define("_ALLSTORIES","ALL stories under");
define("_WILLBEMOVED","will be moved.");
define("_SELECTNEWCAT","Please Select the New Category");
define("_MOVEDONE","Congratulations! The move has been completed!");
define("_CATEXISTS","This Category already exists!");
define("_CATSAVED","Category Saved!");
define("_GOTOADMIN","Go to Admin Section");
define("_CATADDED","New Category Added!");
define("_AUTOSTORYEDIT","Edit Automated Story");
define("_NOTES","Notes");
define("_CHNGPROGRAMSTORY","Select new date for this Story:");
define("_SUBMISSIONSADMIN","Stories Submissions Administration");
define("_DELETESTORY","Delete Story");
define("_EDITARTICLE","Edit Article");
define("_NOSUBMISSIONS","No New Submissions");
define("_NEWSUBMISSIONS","New Stories Submissions");
define("_NOFUNCTIONS","---------");
define("_NOTAUTHORIZED1","You aren't authorized to touch this Article!");
define("_NOTAUTHORIZED2","You can't edit and/or delete articles that you don't published");
define("_WHOLINKS","Who's linking our site?");
define("_DELETEREFERERS","Delete Referers");
define("_POLLSADMIN","Polls/Surveys Administration");
define("_CREATEPOLL","Create a New Poll");
define("_DELETEPOLLS","Delete Polls");
define("_POLLTITLE","Poll Title");
define("_POLLEACHFIELD","Please enter each available option into a single field");
define("_CREATEPOLLBUT","Create Poll");
define("_REMOVEEXISTING","Remove an existing Poll");
define("_POLLDELWARNING","WARNING: The chosen poll will be removed IMMEDIATELY from the database!");
define("_CHOOSEPOLL","Please choose a poll from the list below:");
define("_TOPICSMANAGER","Topics Manager");
define("_CURRENTTOPICS","Current Active Topics");
define("_CLICK2EDIT","Click on Topic to Edit");
define("_ADDATOPIC","Add a New Topic");
define("_TOPICNAME","Topic Name");
define("_TOPICNAME1","(just a name without spaces - max: 20 characters)");
define("_TOPICNAME2","(for example: gamesandhobbies)");
define("_TOPICTEXT","Topic Text");
define("_TOPICTEXT1","(the full topic text or description - max: 40 characters)");
define("_TOPICTEXT2","(for example: Games and Hobbies)");
define("_TOPICIMAGE","Topic Image");
define("_ADDTOPIC","Add Topic");
define("_EDITTOPIC","Edit Topic");
define("_ADDRELATED","Add Related Links");
define("_ACTIVERELATEDLINKS","Active Related Links");
define("_SITENAME","Site Name");
define("_NORELATED","There are no related links for this topic");
define("_EDITRELATED","Edit Related Link");
define("_DELETETOPIC","Delete Topic");
define("_TOPICDELSURE","Are you sure you want to delete Topic");
define("_TOPICDELSURE1","This will delete ALL it's stories and it's comments!");
define("_USERADMIN","User's Administration");
define("_EDITUSER","Edit User");
define("_MODIFY","Modify");
define("_ADDUSER","Add a New User");
define("_FAKEEMAIL","Fake Email");
define("_ALLOWUSERS","Allow other users to view my email address");
define("_ADDUSERBUT","Add User");
define("_USERUPDATE","Update User");
define("_USERID","User ID");
define("_USERNOEXIST","User Doesn't Exists!");
define("_PASSWDNOMATCH","Sorry, the new passwords doesn't match. Go Back and Try Again");
define("_DELETEUSER","Delete User");
define("_SURE2DELETE","Are you sure you want to delete user");
define("_NEEDTOCOMPLETE","You need to complete all required fields");
define("_SITECONFIG","Web Site Configuration");
define("_GENSITEINFO","General Site Info");
define("_SITEURL","Site URL");
define("_SITELOGO","Site Logo");
define("_SITESLOGAN","Site Slogan");
define("_ADMINEMAIL","Administrator Email");
define("_ITEMSTOP","Number of Items in Top Page");
define("_STORIESHOME","Stories Number in Home");
define("_OLDSTORIES","Stories in Old Articles Box");
define("_ACTULTRAMODE","Activate Ultramode?");
define("_DEFAULTTHEME","Default Theme for your site");
define("_SELLANGUAGE","Select the Language for your Site");
define("_LOCALEFORMAT","Locale Time Format");
define("_BANNERSOPT","Banners Options");
define("_STARTDATE","Site Start Date");
define("_ACTBANNERS","Activate Banners in your site?");
define("_FOOTERMSG","Footer Messages");
define("_FOOTERLINE1","Footer Line 1");
define("_FOOTERLINE2","Footer Line 2");
define("_FOOTERLINE3","Footer Line 3");
define("_FOOTERLINE4","Footer Line 4");
define("_BACKENDCONF","Backend Configuration");
define("_BACKENDTITLE","Backend Title");
define("_BACKENDLANG","Backend Language");
define("_MAIL2ADMIN","Mail New Stories to Admin");
define("_NOTIFYSUBMISSION","Notify new submissions by email?");
define("_EMAIL2SENDMSG","Email to send the message");
define("_EMAILSUBJECT","Email Subject");
define("_EMAILMSG","Email Message");
define("_EMAILFROM","Email Account (From)");
define("_COMMENTSMOD","Comments Moderation");
define("_MODTYPE","Type of Moderation");
define("_MODADMIN","Moderation by Admin");
define("_MODUSERS","Moderation by Users");
define("_NOMOD","No Moderation");
define("_COMMENTSOPT","Comments Option");
define("_COMMENTSLIMIT","Comments Limit in Bytes");
define("_ANONYMOUSNAME","Anonymous Default Name");
define("_GRAPHICOPT","Graphics Options");
define("_ADMINGRAPHIC","Graphics in Administration Menu?");
define("_MISCOPT","Miscelaneous Options");
define("_PASSWDLEN","Minimum users password length");
define("_MAXREF","How Many Referers you want as Maximum?");
define("_COMMENTSPOLLS","Activate Comments in Polls?");
define("_ALLOWANONPOST","Allow Anonymous to Post?");
define("_ACTIVATEHTTPREF","Activate HTTP Referers?");
define("_SECTIONSADMIN","Sections Administration");
define("_ACTIVESECTIONS","Current Active Sections");
define("_CLICK2EDITSEC","(Click to Edit)");
define("_ADDSECARTICLE","Add a New Article in Sections");
define("_EDITARTID","Edit Article ID");
define("_ADDSECTION","Add a New Section");
define("_SECTIONNAME","Section Name");
define("_SECTIONIMG","Section Image");
define("_SECIMGEXAMPLE","(Will be under /images/sections/ directory. Example: opinion.gif)");
define("_ADDSECTIONBUT","Add Section");
define("_SELSECTION","Select Section");
define("_SECTIONHAS","This Section has");
define("_ARTICLESATTACH","Articles attached");
define("_40CHARSMAX","(40 characters max.)");
define("_EDITSECTION","Edit Section");
define("_DELSECWARNING","Are you sure you want to delete section");
define("_DELSECWARNING1","This will delete ALL its articles!");
define("_DELARTWARNING","Are you sure you want to delete this article?");
define("_DELSECTION","Delete Section");
define("_DELARTICLE","Delete Article");
define("_EPHEMADMIN","Ephemerids Administration");
define("_ADDEPHEM","Add a New Ephemerid");
define("_EPHEMDESC","Ephemerid Description");
define("_EPHEMMAINT","Ephemerid Maintenance (Edit/Delete):");
define("_EPHEMEDIT","Edit Ephemerids");
define("_REVADMIN","Reviews Administration");
define("_REVTITLE","Reviews Page Title");
define("_REVDESC","Reviews Page Description");
define("_REVWAITING","Reviews Waiting for Validation");
define("_REVIMGINFO","Store your 150*150 image in images/reviews");
define("_TEXT","Text");
define("_IMAGE","Image");
define("_NOREVIEW2ADD","No reviews to add");
define("_ADDREVIEW","Add Review");
define("_CLICK2ADDREVIEW","Click here to write a review");
define("_DELMODREVIEW","Delete / Modify a review");
define("_MODREVINFO","You can simply delete/modify reviews by browsing <a href=\"modules.php?name=Reviews\">Reviews</a> as Admin.");
define("_SIZE","Size");
define("_DOWNLOADSINDB","Downloads in our Database");
define("_DOWNLOADSWAITINGVAL","Downloads Waiting for Validation");
define("_CLEANDOWNLOADSDB","Clean Downloads Votes");
define("_BROKENDOWNLOADSREP","Broken Downloads Reports");
define("_DOWNLOADMODREQUEST","Download Modification Requests");
define("_ADDNEWDOWNLOAD","Add a New Download");
define("_MODDOWNLOAD","Modify a Download");
define("_WEBDOWNLOADSADMIN","Web Downloads Administration");
define("_DNOREPORTEDBROKEN","No reported broken downloads.");
define("_DUSERREPBROKEN","User Reported Broken Downloads");
define("_DIGNOREINFO","Ignore (Deletes all <b><i>requests</i></b> for a given download)");
define("_DDELETEINFO","Delete (Deletes <b><i>broken download</i></b> and <b><i>requests</i></b> for a given download)");
define("_DOWNLOADOWNER","Download Owner");
define("_DUSERMODREQUEST","User Download Modification Requests");
define("_DOWNLOADVALIDATION","Download Validation");
define("_CHECKALLDOWNLOADS","Check ALL Downloads");
define("_VALIDATEDOWNLOADS","Validate Downloads");
define("_NEWDOWNLOADADDED","New Download added to the Database");
define("_LINKSINDB","Links in our Database");
define("_LINKSWAITINGVAL","Links Waiting for Validation");
define("_SUBMITTER","Submitter");
define("_VISIT","Visit");
define("_CLEANLINKSDB","Clean Links Votes");
define("_BROKENLINKSREP","Broken Links Reports");
define("_LINKMODREQUEST","Link Modification Requests");
define("_ADDMAINCATEGORY","Add a MAIN Category");
define("_ADDSUBCATEGORY","Add a SUB-Category");
define("_IN","in");
define("_ADDNEWLINK","Add a New Link");
define("_DESCRIPTION255","Description: (255 characters max)");
define("_MODCATEGORY","Modify a Category");
define("_MODLINK","Modify a Link");
define("_WEBLINKSADMIN","Web Links Administration");
define("_ADDEDITORIAL","Add Editorial");
define("_EDITORIALTITLE","Editorial Title");
define("_EDITORIALTEXT","Editorial Text");
define("_DATEWRITTEN","Date Written");
define("_NOREPORTEDBROKEN","No reported broken links.");
define("_USERREPBROKEN","User Reported Broken Links");
define("_IGNOREINFO","Ignore (Deletes all <b><i>requests</i></b> for a given link)");
define("_DELETEINFO","Delete (Deletes <b><i>broken link</i></b> and <b><i>requests</i></b> for a given link)");
define("_LINK","Link");
define("_LINKOWNER","Link Owner");
define("_IGNORE","Ignore");
define("_USERMODREQUEST","User Link Modification Requests");
define("_ORIGINAL","Original");
define("_PROPOSED","Proposed");
define("_NOMODREQUESTS","There are not any modification requests right now");
define("_SUBCATEGORY","Sub-Category");
define("_OWNER","Owner");
define("_ACCEPT","Accept");
define("_ERRORTHECATEGORY","ERROR: The Category");
define("_ALREADYEXIST","already exist!");
define("_ERRORTHESUBCATEGORY","ERROR: The Sub-Category");
define("_EDITORIALADDED","Editorial added to the Database");
define("_EDITORIALMODIFIED","Editorial Modified");
define("_EDITORIALREMOVED","Editorial removed from the Database");
define("_LINKVALIDATION","Link Validation");
define("_CHECKALLLINKS","Check ALL Links");
define("_CHECKCATEGORIES","Check Categories");
define("_INCLUDESUBCATEGORIES","(include Sub-Categories)");
define("_CHECKSUBCATEGORIES","Check Sub-Categories");
define("_VALIDATELINKS","Validate Links");
define("_FAILED","Failed!");
define("_BEPATIENT","(please be patient)");
define("_VALIDATINGCAT","Validating Category (and all subcategories)");
define("_VALIDATINGSUBCAT","Validating Sub-Category");
define("_ERRORURLEXIST","ERROR: This URL is already listed in the Database!");
define("_ERRORNOTITLE","ERROR: You need to type a TITLE for your URL!");
define("_ERRORNOURL","ERROR: You need to type a URL for your URL!");
define("_ERRORNODESCRIPTION","ERROR: You need to type a DESCRIPTION for your URL!");
define("_NEWLINKADDED","New Link added to the Database");
define("_YOURLINKAT","Your Link at");
define("_YOUCANBROWSEUS","You can browse our search engine at:");
define("_THANKS4YOURSUBMISSION","Thanks for your submission!");
define("_TEAM","Team.");
define("_MESSAGES","Messages");
define("_MESSAGESADMIN","Messages Administration");
define("_MESSAGETITLE","Title");
define("_MESSAGECONTENT","Content");
define("_EXPIRATION","Expiration");
define("_VIEWPRIV","Who can View This?");
define("_MVADMIN","Administrators Only");
define("_MVUSERS","Registered Users Only");
define("_MVANON","Anonymous Users Only");
define("_MVALL","All Visitors");
define("_CHANGEDATE","Change start date to today?");
define("_IFYOUACTIVE","(If you Active this Message now, the start date will be today)");
define("_FILENAME","Filename");
define("_FILEINCLUDE","(Select a custom Block to be included. All other fields will be ignored)");
define("_BLOCKFILE","(Block File)");
define("_EDITPOLL","Edit Polls");
define("_CHOOSEPOLLEDIT","Choose the Poll you want to edit:");
define("_ACTIVATECOMMENTS","Activate Comments for this Story?");
define("_COMMENTSARTICLES","Activate Comments in Articles?");
define("_MULTILINGUALOPT","Multilingual Options");
define("_ACTMULTILINGUAL","Activate Multilingual features? ");
define("_ACTUSEFLAGS","Display flags instead of a dropdown box? ");
define("_LANGUAGE","Language");
define("_EDITMSG","Edit message");
define("_ADDMSG","Add message");
define("_ALLMESSAGES","Overview messages");
define("_VIEW","Visible to");
define("_REMOVEMSG","Are you sure you want to remove this message ? ");
define("_ANNOUNCEPOLL","Announce this new Survey in your site");
define("_LEAVEBLANK","(Leave blank to create a new survey without announce it)");
define("_POLLEDIT","Edit Poll:");
define("_ATTACHAPOLL","Attach a Poll to this article");
define("_LEAVEBLANKTONOTATTACH","(Leave blank to post the article without any attached Poll)<br>(NOTE: Automated/Programmed news can't have attached Polls)");
define("_MODULES","Modules");
define("_MODULESADMIN","Modules Administration");
define("_MODULESADDONS","Modules and Addons");
define("_MODULESACTIVATION","See your Modules/Addons current status and change it by Activating or Deactivating them.<br>New Modules copied on the <i>/modules/</i> directory will be automaticaly added with <i>Inactive</i> status to the database when you reload this page.<br>If you want to remove a module just delete it from the <i>/modules/</i> directory, the system will automaticaly update your database to show the changes.");
define("_NEWSLETTER","Newsletter");
define("_MASSMAIL","A Massive e-mail to ALL users");
define("_ANEWSLETTER","A Newsletter to subscribed users only");
define("_WHATTODO","What do you want to send?");
define("_SUBSCRIBEDUSERS","Subscribed Users");
define("_NYOUAREABOUTTOSEND","You're about to send a Newsletter to subscribed users.");
define("_NUSERWILLRECEIVE","Users will receive this Newsletter.");
define("_REVIEWTEXT","Please review and check your text:");
define("_NAREYOUSURE2SEND","Are you sure to send this Newsletter now?");
define("_MYOUAREABOUTTOSEND","You're about to send a Massive e-mail to ALL registered users.");
define("_MUSERWILLRECEIVE","Users will receive this Mail.");
define("_MAREYOUSURE2SEND","Are you sure to send this Massive Email now?");
define("_POSSIBLESPAM","Please note that some users may feel disturbed by massive email and may consider this as Spam!");
define("_MASSEMAIL","Massive Email");
define("_MANYUSERSNOTE","WARNING! There are many users that will receive this text. Please wait until the script finish the operation. This can take some minutes to complete!");
define("_NLUNSUBSCRIBE","=========================================================\nYou're receiving this Newsletter because you selected to receive it from your user page at $sitename.\nYou can unsubscribe from this service by clicking in the following URL:\n\n$nukeurl/modules.php?name=Your_Account&op=edituser\"\n\nthen select \"No\" from the option to Receive Newsletter by Email and save your changes, if you need more assistance please contact $sitename administrator.");
define("_NEWSLETTERSENT","The Newsletter has been sent.");
define("_MASSEMAILSENT","Massive Email to all registered users has been sent.");
define("_MASSEMAILMSG","=========================================================\nYou're receiving this email because you're a registered user of $sitename. We hope that this email didn't disturbed you and in some manner contributes to improve our services.");
define("_BBFORUM","Forum");
define("_BBDELFORUM","Are you sure you want to delete this Forum and ALL its Posts?");
define("_BBDELCAT","Are you sure you want to delete this Category and ALL its Forums and Posts?");
define("_BBAEDITCAT","Edit Categories");
define("_BBACAT","Categories");
define("_BBASAVECHANGES","Save Changes");
define("_BBAFCAT","Forum Categories");
define("_BBAORDER","Order");
define("_BBANOOFF","No. of Forum(s)");
define("_BBAFUNC","Function");
define("_BBAEDIT","Edit");
define("_BBADELETE","Delete");
define("_BBAADDCAT","Add Categories");
define("_BBAADD","Add");
define("_BBACATLOWEST","This category is already the lowest down.");
define("_BBACATHIGHEST","This category is already the highest up.");
define("_BBABACKTOFORUM","Go back to forum admin");
define("_BBAACTIVE","Active");
define("_BBAICONS","Icons");
define("_BBAEMO","Emotions");
define("_BBACODE","Code");
define("_BBAFSMILIES","Forum Smilies");
define("_BBAADDSMILIES","Add Smilies");
define("_BBAEDITSMILIES","Edit Smilies");
define("_BBAACT","Activated");
define("_BBAWARNING","WARNING: Are you sure you want to delete this Smilies?");
define("_BBAYES","Yes");
define("_BBANO","No");
define("_BBAFLISTED","Forum(s) Listed");
define("_BBAFNAME","Forum Name");
define("_BBAFDESC","Forum Description");
define("_BBAFMOD","Moderator");
define("_BBAFACC","Access");
define("_BBATYPE","Type");
define("_BBAANONPOST","Anonymous Posting");
define("_BBAREGUSER","Registered User");
define("_BBAMODADMIN","Moderators/Administrator");
define("_BBAPUBLIC","Public");
define("_BBAPRIVATE","Private");
define("_BBAADDMOREF","Add More Forum for");
define("_BBAACCLEV","Access Level");
define("_BBAEDITF","Edit Forum(s)");
define("_BBAAUP","Forum Categories Order Up");
define("_BBAADOWN","Forum Categories Order Down");
define("_BBACURMOD","Current Moderator");
define("_BBANOMOD","No Moderators Assigned");
define("_BBAREMOVE","Remove");
define("_BBAAMOD","Add Moderator");
define("_BBACHGCAT","Change Categories");
define("_BBAPRIVSET","Add User");
define("_BBAWORD","Word");
define("_BBAREPLACEMENT","Replacement");
define("_BBAADDCENCOR","Add New censor word");
define("_BBAWCS","Forum Word Censor System");
define("_BBAEDITWORD","Edit Censor Word");
define("_BBACENCORWARN","WARNING: Are you sure you want to delete this censor words?");
define("_BBAFBANIP","Current Banned IPs");
define("_BBABANIP","IP Address");
define("_BBADURATION","Durations");
define("_BBAFBANUID","Current Banned UserName");
define("_BBABANUID","Username");
define("_BBAIPUNAME","IP/Username");
define("_BBAADDBAN","Add new banned rules");
define("_BBAWARNBAN","WARNING: Are you sure you want to delete this banned rules?");
define("_BBAEDITPRIVF","Editing Forum Permissions for:");
define("_FIXBLOCKS","Fix Block's Weight Conflicts");
define("_FORUMSADMIN","Forums Administration");
define("_BBSELECTACTION","Select an Administration Task:");
define("_FORUMMANAGER","Forum Manager");
define("_FORUMRANKS","Ranks");
define("_FORUMCONFIG","Config");
define("_BBAFORUMICONS","Icons");
define("_BBAFORUMCEN","Censor");
define("_BBAFORUMBAN","Ban System");
define("_BBRANKTITLE","Rank Title");
define("_BBRANKMINP","Min. Ranks");
define("_BBRANKMAXP","Max. Ranks");
define("_BBRANKSPEC","Special");
define("_BBRANKIMM","Images");
define("_BBRANKADD","Add New Ranks");
define("_BBEMAILFROM","Email From Address:");
define("_BBEMAILEXPL","(This is the address that will appear on every email sent by the forums)");
define("_BBMAILSIG","Email Signature:");
define("_BBSIGEXPL","(This is the signature that will appear on every email sent by the forums)");
define("_HTMLALLOW","Allow HTML:");
define("_BBCODEALLOW","Allow BBCode:");
define("_BBALLOWSIG","Allow Signatures:");
define("_BBHOT","Hot Topic Threshold:");
define("_BBPPP","Posts Per Page:");
define("_BBPPPEXPL","(This is the number of topics per forum that will be displayed per page of a forum)");
define("_BBTOPPF","Topics Per Forum:");
define("_BBTOPPFEXP","(This is the number of topics per forum that will be displayed per page of a forum)");
define("_EZTRANSFERLINKS","Transfer all links from category");
define("_EZTRANSFER","Transfer");
define("_DELEZLINKCATWARNING","WARNING : Are you sure you want to delete this category ? You will delete all sub-categories and attached links as well !");
define("_EZTHEREIS","There is");
define("_EZSUBCAT","sub-categories");
define("_EZATTACHEDTOCAT","under this category");
define("_EZBROKENLINKS","Broken Links");
define("_CONTENTMANAGER","Content Manager");
define("_DELCONTWARNING","Are you sure you want to delete the page");
define("_DELCONTENT","Delete Page");
define("_SAVEDATABASE","Backup DB");
define("_ENCYCLOPEDIA","Encyclopedia");
define("_ENCYCLOPEDIAMANAGER","Encyclopedia Manager");
define("_DELENCYCLOPEDIA","Delete Encyclopedia");
define("_DELENCYCONTWARNING","Are you sure you want to delete this Encyclopedia and ALL its content?");
define("_DELENCYCLOPEDIATEXT","Delete Encyclopedia Terms");
define("_DELENCYTEXTWARNING","Are you sure you want to delete this Term?");
define("_CURRENTSTATUS","Current Status");
define("_ADDANEWPAGE","Add a New Page");
define("_CSUBTITLE","Sub-Title");
define("_HEADERTEXT","Header Text");
define("_PAGETEXT","Page Text");
define("_FOOTERTEXT","Footer Text");
define("_ACTIVATEPAGE","Activate This Page?");
define("_EDITPAGECONTENT","Edit Page Content");
define("_TERMS","Terms");
define("_ADDNEWENCYCLOPEDIA","Add a New Encyclopedia");
define("_ADDNEWENCYTERM","Add a New Encyclopedia Term");
define("_TERMTEXT","Term Text");
define("_MOVETERMS","Move Terms");
define("_MOVEALLTERMSFROM","Move ALL Terms From");
define("_EDITENCYCLOPEDIA","Edit Encyclopedia");
define("_ENCYTERMSEDIT","Encyclopedia Terms Edit");
define("_SELECTONETERM","Please select one term from the following list:");
define("_NOCONTENTFORLETTER","Sorry, there isn't any content for the letter");
define("_CHANGETOENCY","Change to Encyclopedia");
define("_DBOPTIMIZATION","Database Optimization");
define("_OPTIMIZINGDB","Optimizing the Database:");
define("_TABLE","Table");
define("_SPACESAVED","Space Saved");
define("_ALREADYOPTIMIZED","Already optimized");
define("_OPTIMIZED","Optimized!");
define("_OPTIMIZATIONRESULTS","Optimization Results");
define("_TOTALSPACESAVED","Total Space Saved:");
define("_YOUHAVERUNSCRIPT","You have run this script:");
define("_KBSAVED","Kb saved since its first execution!");
define("_TIMES","times");
define("_CUSTOMTITLE","Custom Title");
define("_CHANGEMODNAME","Change Module Name");
define("_CUSTOMMODNAME","Custom Module Name:");
define("_MODULEEDIT","Modules Edit");
define("_BLOCKFILE2","FILE");
define("_BLOCKSYSTEM","SYSTEM");
define("_DEFHOMEMODULE","Default Homepage Module");
define("_MODULEINHOME","Module Loaded in the Homepage:");
define("_CHANGE","Change");
define("_INHOME","In Home");
define("_MODULEHOMENOTE","<b>-= WARNING =-</b><br>Bold module's title represents the module you have in the Homepage.<br>You can't Deactivate or Restrict this module while it's the default one!<br>If you delete the module's directory you'll see and error in the Homepage.<br>Also, this module has been replaced with <i>Home</i> link in the modules block.");
define("_PUTINHOME","Put in Home");
define("_SURETOCHANGEMOD","Are you sure you want to change your Homepage from");
define("_EZTRANSFERDOWNLOADS","Transfer all downloads from category");
define("_DELEZDOWNLOADSCATWARNING","WARNING : Are you sure you want to delete this category? You will delete all sub-categories and attached downloads as well!");
define("_DELCONTENTCAT","WARNING: Are you sure you want to delete this category? Pages under this category, if they exist, will not be removed, but will not be attached to any category.");
define("_DELCATEGORY","Delete Category");
define("_DOWNLOADTITLE","Download Title");
define("_CENTER","Center");
define("_CENTERBLOCK","Center Block");
define("_ADMINISTRATION","Administration");
define("_NOADMINYET","There are no Administrators Accounts yet, proceeed to create the Super User:");
define("_CREATEUSERDATA","Do you want to create a normal user with the same data?");
define("_NORMAL","Normal");
define("_INACTIVEBANNERS","Inactive Banners");

?>